% Setup_Demo is used to set the task, the visual input and the plotting
% of the simulation. Only this file has to changed when running a
% simulation with FEF_DEMO.
%
% created: Jakob Heinzle 01/07

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% select the task you want to run and define the input.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

select_task=1; % 5= scanning  4= reading 1=example of a normal forward saccade
% 2=example of a long backward saccade 3=example of a 
% only reading and scanning works in this version, for speed reasons.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define the input arrays and set the feature assigned to the target.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if select_task==1
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('% Example normal forward saccade');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    random_trial=0; % 0: random generators are initialized to give stable results
                    % 1: random generators are initialized using time --> skipping might not 
                    % skip but be a normal saccade.
    rand('state',12000);
    randn('state',8000);
    inarray1=[0 0 0 0 0 0 0 0 0 0 1 0 1 1 1 0 1 1 0 1 0];
    tmax=400;
    tfix_on=0;
    tfix_off=50;
    tvisual_on=50;
    tvisual_off=tmax;
    tvisual_transoff=90;
    k=1;
    uu=find(diff([inarray1 0]));
    featarray=zeros(1,21);
    for k=1:2:length(uu);
        featarray(uu(k)+1:uu(k+1))=-uu(k)+uu(k+1)+10;
    end
    read_on=1;
elseif select_task==2
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('% Example large backward saccade');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
     random_trial=0;
    rand('state',12000);
    randn('state',8000);
    inarray1=[1 1 1 0 1 0 1 1 0 1 1 0 0 0 0 0 0 0 0 0 0];
    tmax=400;
    tfix_on=0;
    tfix_off=50;
    tvisual_on=50;
    tvisual_off=tmax;
    tvisual_transoff=90;
    k=1;
    uu=find(diff([inarray1 0]));
    featarray=zeros(1,21);
    if inarray1(1)==1
        uu=[0 uu];
    end
    for k=1:2:length(uu);
        featarray(uu(k)+1:uu(k+1))=-uu(k)+uu(k+1)+10;
    end
    read_on=1;
elseif select_task==3
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('% Example skipping of short word');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
     random_trial=0;
    rand('state',12000);
    randn('state',8000);
    inarray1=[0 0 0 0 0 0 0 0 0 0 1 1 0 1 0 1 1 0 1 1 1];
    tmax=550;
    tfix_on=0;
    tfix_off=50;
    tvisual_on=50;
    tvisual_off=tmax;
    tvisual_transoff=90;
    k=1;
    uu=find(diff([inarray1 0]));
    featarray=zeros(1,21);
    for k=1:2:length(uu);
        featarray(uu(k)+1:uu(k+1))=-uu(k)+uu(k+1)+10;
    end
    read_on=1;
elseif select_task==4
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('% Reading task');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    random_trial=1;
    inarray1=[0 0 0 0 0 0 0 0 0 0 1 1 0 1 0 1 1 0 1 1 1];
    tmax=2000;
    tfix_on=0;
    tfix_off=50;
    tvisual_on=50;
    tvisual_off=tmax;
    tvisual_transoff=90;
    k=1;
    uu=find(diff([inarray1 0]));
    featarray=zeros(1,21);
    for k=1:2:length(uu);
        featarray(uu(k)+1:uu(k+1))=-uu(k)+uu(k+1)+10;
    end
    read_on=1; %parameter needed for changes in rule input.
elseif select_task==5
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('% Scanning task');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    random_trial=1;
    inarray1=[0 0 0 0.9 0 0 1 0 0 0 0.8 0 1 0 0.9 0 0 0.8 0 0 0];
    featarray=(inarray1>0)*13; %objects are slowly recognized.
    tfix_on=0;
    tfix_off=50;
    tmax=2000;
    tvisual_on=50;
    tvisual_off=tmax;
    tvisual_transoff=90;
    read_on=0;
end

%=====================================================================
% Printing options (can also be defined manually
% 
% The population given here will be plotted at the end of the simulations: 
% -10 is the most left position, 0 the fovea and 10 the most right
% position.
%=====================================================================

set_print_manually=0; % 0: all positions with saccades to them are plotted.
% 1: the print positions can be defined manually, vector with values
% between -10 and 10
print_positions=-10:10; % print positions for plotting all positions

%=====================================================================
% Initialize graphics (displays only a single layer, here layer 4)
%=====================================================================

skip = 5;  % refresh interval for plot in ms;
t=0;
figure(1);
clf;
subplot(4,1,1);
hInp=bar(-10:10,zeros(1,21));
axis([-10.5 10.5 0 1.5]);
hold on;
xlabel('Retinotopic position')
ylabel('Input strength')
title('Input to layer 4')
hText=text(-10,1.1,[int2str(round(t)),' ms'],'FontSize',18);

subplot(4,1,2);
hL4=bar(-10:10,zeros(1,21));
axis([-10.5 10.5 0 100]);
hold on;
xlabel('Retinotopic position')
ylabel('Firing Rate')
title('Layer 4E')

subplot(4,1,3);
hL23=bar(-10:10,zeros(1,21));
axis([-10.5 10.5 0 100]);
hold on;
xlabel('Retinotopic position')
ylabel('Firing Rate')
title('Layer 2/3 E')

subplot(4,1,4);
hL5=bar(-10:10,zeros(1,21));
axis([-10.5 10.5 0 100]);
hold on;
xlabel('Retinotopic position')
ylabel('Firing Rate')
title('Layer 5 E')

%====================================================================
% Define which values to save after the simulation.
%====================================================================

savepath=['save ''FEF_RESULT',int2str(select_task),''' E4 I4 E23 I23 E5R E5B I5R I5B E6A E6S ERb ERr IRb IF EFp EFf EFf ATT IFIX FOVEA'];
